import { UserMentionMetadata } from "./userMentionMetadata";
/**
 * Annotations associated with the plain-text body of the message.  Example
 * plain-text message body: ``` Hello @FooBot how are you!" ```  The
 * corresponding annotations metadata: ``` "annotations":[{
 * "type":"USER_MENTION",   "startIndex":6,
 * "length":7,   "userMention": {     "user": {
 * "name":"users/107946847022116401880",
 * "displayName":"FooBot",
 * "avatarUrl":"https://goo.gl/aeDtrS",
 * "type":"BOT"     },
 * "type":"MENTION"    } }] ```
 */
export declare class Annotation {
    /**
     * Length of the substring in the plain-text message body this annotation
     * corresponds to.
     */
    private length?;
    /**
     * Start index (0-based, inclusive) in the plain-text message body this
     * annotation corresponds to.
     */
    private startIndex?;
    /**
     * The type of this annotation.
     */
    private type?;
    /**
     * The metadata of user mention.
     */
    private userMention?;
    getLength(): number;
    setLength(value: number): Annotation;
    getStartIndex(): number;
    setStartIndex(value: number): Annotation;
    getType(): string;
    setType(value: string): Annotation;
    getUserMention(): UserMentionMetadata;
    setUserMention(value: UserMentionMetadata): Annotation;
}
