import { User } from "./user";
import { Space } from "./space";
import { Thread } from "./thread";
import { ActionResponse } from "./actionResponse";
import { Card } from "./card";
/**
 * A message in Hangouts Chat.
 */
export declare class Message {
    /**
     * Input only. Parameters that a bot can use to configure how its response
     * is posted.
     */
    private actionResponse?;
    /**
     * Plain-text body of the message with all bot mentions stripped out.
     */
    private argumentText?;
    /**
     * Rich, formatted and interactive cards that can be used to display UI
     * elements such as: formatted texts, buttons, clickable images. Cards are
     * normally displayed below the plain-text body of the message.
     */
    private cards?;
    /**
     * A plain-text description of the message'#39;s cards, used when the actual
     * cards cannot be displayed (e.g. mobile notifications).
     */
    private fallbackText?;
    /**
     * Text for generating preview chips. This text will not be displayed to the
     * user, but any links to images, web pages, videos, etc. included here will
     * generate preview chips.
     */
    private previewText?;
    /**
     * The user who created the message.
     */
    private sender?;
    /**
     * The space the message belongs to.
     */
    private space?;
    /**
     * Plain-text body of the message.
     */
    private text?;
    /**
     * The thread the message belongs to.
     */
    private thread?;
    getActionResponse(): ActionResponse;
    setActionResponse(value: ActionResponse): Message;
    getArgumentText(): string;
    setArgumentText(value: string): Message;
    getCards(): Card[];
    addCard(value: Card): Message;
    setCards(value: Card[]): Message;
    getFallbackText(): string;
    setFallbackText(value: string): Message;
    getPreviewText(): string;
    setPreviewText(value: string): Message;
    getSender(): User;
    setSender(value: User): Message;
    getSpace(): Space;
    setSpace(value: Space): Message;
    getText(): string;
    setText(value: string): Message;
    getThread(): Thread;
    setThread(value: Thread): Message;
}
